# frozen_string_literal: true

# modele HOUSING_INTENTION === APPLICATION dans les dso actuels

# Legende
# Les script a plusieurs parties indique que les bash (Batch dans l'app)
# peuvent s'initier avec differents types de source
# Le besoin est donc d'isoler la logique associee au modele actuel
# ne pas oublier d'indexer les champs simples

class Hermes::HousingApplication_old < Hermes::ApplicationRecord
  hermes_workers "scorer"

  field :has_applicated, type: Boolean, default: false

  belongs_to :applicant, class_name: 'Hermes::Applicant'
  belongs_to :housing_request, class_name: 'Hermes::HousingRequest'
  belongs_to :housing_offer, class_name: 'Hermes::HousingOffer'

  writer_roles 'Superadmin', 'Administrator'
  reader_roles 'Manager'
  owner_field :user_id

  before_save # https://dev.hermes.openstack.local/admin/families/5d123bc04ac06e4ca38c1671/mapping

  # def process(applicant, housing_request, housing_offer)
  #   # https://dev.hermes.openstack.local/admin/batchs/5d026a674ac06e3ed0d93295/script
  # end

  class << self
    def process_with(applicant, housing_request, housing_offer)
      applicant = applicant.is_a?(Hermes::Applicant) ? applicant : Hermes::Applicant.find_by(id: applicant)
      housing_request = housing_request.is_a?(Hermes::HousingRequest) ? housing_request : Hermes::HousingRequest.find_by(id: housing_request)
      housing_offer = housing_offer.is_a?(Hermes::HousingOffer) ? housing_offer : Hermes::HousingOffer.find_by(id: housing_offer)

      Scorer.process(applicant, housing_request, housing_offer)
    end
  end

  def get_applicant_active_request
    applicant.first_active_request
  end

  def process
    Scorer.process(applicant, get_applicant_active_request, housing_offer)
  end
end
